@@ -26,10 +26,10 @@ import logging
 import os
 import re
 import requests
+import six
+from six.moves.urllib import parse
 import subprocess
 import time
-import urllib
-import urlparse
 
 DESCRIPTION_MAX = 1024
 
@@ -54,7 +54,7 @@ class GitHub2GitLab:
             self.args.gitlab_repo = self.args.github_repo
         (self.args.gitlab_namespace,
          self.args.gitlab_name) = self.args.gitlab_repo.split('/')
-        self.args.gitlab_repo = urllib.quote_plus(self.args.gitlab_repo)
+        self.args.gitlab_repo = parse.quote_plus(self.args.gitlab_repo)
 
         self.github = {
             'url': "https://api.github.com",
@@ -140,7 +140,7 @@ class GitHub2GitLab:
         try:
             output = subprocess.check_output(command, stderr=subprocess.STDOUT,
                                              shell=True)
-        except subprocess.CalledProcessError, e:
+        except subprocess.CalledProcessError as e:
             output = e.output
             raise e
         finally:
@@ -186,7 +186,7 @@ class GitHub2GitLab:
         query = {'private_token': g['token']}
         keys = requests.get(url, params=query).json()
         logging.debug("looking for '" + public_key + "' in " + str(keys))
-        if (filter(lambda key: key['key'] == public_key, keys)):
+        if (list(filter(lambda key: key['key'] == public_key, keys))):
             logging.debug(self.args.ssh_public_key + " already exists")
             return None
         else:
@@ -240,7 +240,7 @@ class GitHub2GitLab:
     def update_merge_pull(self):
         self.merge2pull = {}
         self.pull2merge = {}
-        for (id, merge) in self.merge_requests.iteritems():
+        for (id, merge) in six.iteritems(self.merge_requests):
             pull = merge['source_branch'].split('/')
             if len(pull) == 3:
                 number = pull[1]
@@ -311,7 +311,7 @@ class GitHub2GitLab:
 
             if merge:
                 updates = {}
-                for (pull_field, merge_field) in pull_f2merge_f.iteritems():
+                for (pull_field, merge_field) in six.iteritems(pull_f2merge_f):
                     if not self.field_equal(pull,
                                             pull_field,
                                             pull[pull_field],
@@ -332,7 +332,7 @@ class GitHub2GitLab:
                                   self.github['repo'] + "/" +
                                   "pull/" + number + " == " +
                                   self.gitlab['host'] + "/" +
-                                  urllib.unquote(self.gitlab['repo']) + "/" +
+                                  parse.unquote(self.gitlab['repo']) + "/" +
                                   "merge_requests/" + str(merge['iid']))
 
     def rev_parse(self, pull, revision):
@@ -355,13 +355,14 @@ class GitHub2GitLab:
         "Log the payload that cannot be parsed"
         try:
             return json.loads(payload)
-        except ValueError, e:
+        except ValueError as e:
             logging.error("unable to json.loads(" + payload + ")")
             raise e
 
     def get(self, url, query, cache):
         payloads_file = (self.tmpdir + "/" +
-                         hashlib.sha1(url).hexdigest() + ".json")
+                         hashlib.sha1(url.encode('utf-8')).hexdigest() +
+                         ".json")
         if (not cache or not os.access(payloads_file, 0) or
                 time.time() - os.stat(payloads_file).st_mtime > 24 * 60 * 60):
             payloads = []
@@ -375,12 +376,12 @@ class GitHub2GitLab:
                     if 'rel="next"' in link:
                         m = re.search('<(.*)>', link)
                         if m:
-                            parsed_url = urlparse.urlparse(m.group(1))
+                            parsed_url = parse.urlparse(m.group(1))
                             # append query in case it was not preserved
                             # (gitlab has that problem)
                             next_query = query
                             next_query.update(
-                                dict(urlparse.parse_qsl(parsed_url.query))
+                                dict(parse.parse_qsl(parsed_url.query))
                             )
             if cache:
                 with open(payloads_file, 'w') as f:
@@ -427,7 +428,7 @@ class GitHub2GitLab:
             raise ValueError(result.text)
         merge = result.json()
         logging.debug('merge ' + str(merge))
-        for (key, value) in query.iteritems():
+        for (key, value) in six.iteritems(query):
             if key == 'private_token':
                 continue
             if value != merge.get(key):
@@ -458,7 +459,7 @@ class GitHub2GitLab:
 
     def verify_merge_update(self, updates, result):
         g = self.gitlab
-        for (key, value) in updates.iteritems():
+        for (key, value) in six.iteritems(updates):
             if key == 'private_token':
                 continue
             if key == 'state_event':
@@ -466,7 +467,7 @@ class GitHub2GitLab:
                 value = self.STATE_EVENT2MERGE_STATE[updates['state_event']]
             result_value = result.get(key) or ''
             if value != result_value:
-                url = (g['host'] + "/" + urllib.unquote(g['repo']) + "/" +
+                url = (g['host'] + "/" + parse.unquote(g['repo']) + "/" +
                        "merge_requests/" + str(result['iid']))
                 raise ValueError("{url}: {key} value expected to be {value}"
                                  " but is {result}".format(
