@@ -19,6 +19,7 @@
 #
 import fixtures
 import json
+import logging
 import mock
 import os
 import tempfile
@@ -26,6 +27,10 @@ import testtools
 
 from github2gitlab import main
 
+logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
+                    level=logging.DEBUG)
+
+
 class TestGitHub2GitLab(testtools.TestCase):
 
     def setUp(self):
@@ -428,3 +433,7 @@ class TestGitHub2GitLabNoSetup(testtools.TestCase):
         r = main.GitHub2GitLab.json_loads('{}')
         self.assertEquals({}, r)
         self.assertRaises(ValueError, main.GitHub2GitLab.json_loads, ']')
+
+# Local Variables:
+# compile-command: "../.tox/py33/bin/py.test test_github2gitlab.py"
+# End:
